@@ -14,7 +14,7 @@ is available at U{http://www.opensource.org/licenses/bsd-license.php}
 
 import gtk
 import gobject
-import pyLinAcc
+import pyatspi
 import atk, os
 from icons import getIcon
 from node import Node
@@ -34,9 +34,9 @@ class AccessibleModel(gtk.TreeStore, Tools):
   that are being viewed. This cuts short on a lot of potential overhead.
 
   @ivar desktop: The desktop accessible. It holds references to all the 
-  application L{pyLinAcc.Accessible}s
-  @type desktop: L{pyLinAcc.Accessible}
-  @ivar acc_cache: A list of L{pyLinAcc.Accessible}s that are currently
+  application L{Accessibility.Accessible}s
+  @type desktop: L{Accessibility.Accessible}
+  @ivar acc_cache: A list of L{Accessibility.Accessible}s that are currently
   resident in the model. This helps with faster searching.
   @type acc_cache: list
   '''
@@ -116,10 +116,10 @@ class AccessibleModel(gtk.TreeStore, Tools):
 
   def isInModel(self, acc):
     '''
-    Checks if the given L{pyLinAcc.Accessible} is resident in the model.
+    Checks if the given L{Accessibility.Accessible} is resident in the model.
 
-    @param acc: The L{pyLinAcc.Accessible} to check.
-    @type acc: L{pyLinAcc.Accessible}
+    @param acc: The L{Accessibility.Accessible} to check.
+    @type acc: L{Accessibility.Accessible}
 
     @return: True if it is in the model.
     @rtype: boolean
@@ -147,12 +147,12 @@ class AccessibleModel(gtk.TreeStore, Tools):
 
   def _prepopLevel(self, parent, iter):
     '''
-    Pre-populate a row. If a L{pyLinAcc.Accessible} of the given row has children,
+    Pre-populate a row. If a L{Accessibility.Accessible} of the given row has children,
     we need to add to it one dummy child row so that the expander will show and
     enable the user to expand it. We populate the children rows at expansion time.
 
     @param parent: The given row's accessible.
-    @type parent: L{pyLinAcc.Accessible}
+    @type parent: L{Accessibility.Accessible}
     @param iter: Th iter of the row that needs to be pre-populated
     @type iter: L{gtk.TreeIter}
     '''
@@ -166,7 +166,7 @@ class AccessibleModel(gtk.TreeStore, Tools):
     Populate a row with children rows, according to the row's accessible's children.
 
     @param parent: The given row's accessible.
-    @type parent: L{pyLinAcc.Accessible}
+    @type parent: L{Accessibility.Accessible}
     @param iter: Th iter of the row that needs to be populated
     @type iter: L{gtk.TreeIter}
     
@@ -193,7 +193,7 @@ class AccessibleModel(gtk.TreeStore, Tools):
     I{Note:} The accessible does not necessarily need to be resident in the model.
     
     @param acc: The accessible we want a path of.
-    @type acc: L{pyLinAcc.Accessible}
+    @type acc: L{Accessibility.Accessible}
     
     @return: The path to the accessible.
     @rtype: tuple
@@ -219,7 +219,7 @@ class AccessibleModel(gtk.TreeStore, Tools):
     model fields.
 
     @param accessible: Accessible object
-    @type accessible: pyLinAcc.Accessible
+    @type accessible: L{Accessibility.Accessible}
     @param filled: Should the row be considered populated?
     @type filled: boolean
     @param name: Optional name to use as an override for the name gotten from
@@ -247,14 +247,12 @@ class AccessibleTreeView(gtk.TreeView, Tools):
   updates automatically in response to at-spi children change events.
 
   @ivar desktop: The desktop accessible. It holds references to all the 
-  application L{pyLinAcc.Accessible}s
-  @type desktop: L{pyLinAcc.Accessible}
+  application L{Accessibility.Accessible}s
+  @type desktop: L{Accessibility.Accessible}
   @ivar node: An object with a reference to the currently selected accessible.
   @type node: L{Node}
   @ivar model: The data model of this treeview.
   @type model: L{AccessibleModel}
-  @ivar event_manager: The event manager we use for handling at-spi events.
-  @type event_manager: L{pyLinAcc.Event.Manager}
   '''
   def __init__(self):
     '''
@@ -263,7 +261,7 @@ class AccessibleTreeView(gtk.TreeView, Tools):
     '''
     gtk.TreeView.__init__(self)
 
-    self.desktop = pyLinAcc.Registry.getDesktop(0)
+    self.desktop = pyatspi.Registry.getDesktop(0)
     self.node = Node()
     self.node.update(self.desktop)
     self._changed_handler = self.node.connect('accessible_changed',
@@ -303,19 +301,11 @@ class AccessibleTreeView(gtk.TreeView, Tools):
     selection = self.get_selection()
     selection.unselect_all()
     selection.connect('changed', self._onSelectionChanged)
-    selection.set_select_function(self._selectFunc, full=True)
+    selection.set_select_function(self._selectFunc)
     self.connect('row-expanded', self._onExpanded)
-    self.event_manager = pyLinAcc.Event.Manager()
-    self.event_manager.addClient(self._accEventChildChanged, 
-                                 'object:children-changed')
+    pyatspi.Registry.registerEventListener(self._accEventChildChanged, 
+                                           'object:children-changed')
 
-  def destroy(self):
-    '''
-    Overrides superclass's destroy method.
-    Used for explicitly closing the L{pyLinAcc.Event.Manager} or bad things happen.
-    '''
-    self.event_manager.close()
-    gtk.TreeView.destroy(self)
 
   def refreshTopLevel(self):
     '''
@@ -364,7 +354,7 @@ class AccessibleTreeView(gtk.TreeView, Tools):
     Event handler for "object:children-changed". Updates the treeview accordingly.
     
     @param event: The event which triggered this handler.
-    @type event: L{pyLinAcc.Event}
+    @type event: L{pyatspi.event.Event}
     '''
     if self.isMyApp(event.source):
       # Bad karma
@@ -391,7 +381,7 @@ class AccessibleTreeView(gtk.TreeView, Tools):
     @param iter: Th iter of the row that needs a child added. 
     @type iter: L{gtk.TreeIter}
     @param parent: The given row's accessible.
-    @type parent: L{pyLinAcc.Accessible}
+    @type parent: L{Accessibility.Accessible}
     '''
     old_children = set(self.model.getChildrenAccs(iter))
     new_children = set(list(parent))
@@ -418,7 +408,7 @@ class AccessibleTreeView(gtk.TreeView, Tools):
     takes wnck a while to load an application's icon at application startup.
 
     @param app: The given application's accessible.
-    @type app: L{pyLinAcc.Accessible}
+    @type app: L{Accessibility.Accessible}
     '''
     path = self.model.getAccPath(app)
     try:
@@ -434,7 +424,7 @@ class AccessibleTreeView(gtk.TreeView, Tools):
     @param parent_iter: Th iter of the row that needs a child removed. 
     @type parent_iter: L{gtk.TreeIter}
     @param parent: The given row's accessible.
-    @type parent: L{pyLinAcc.Accessible}
+    @type parent: L{Accessibility.Accessible}
     '''
     if parent_iter:
       iter = self.model.iter_children(parent_iter)
@@ -500,7 +490,7 @@ class AccessibleTreeView(gtk.TreeView, Tools):
     @param node: The L{node} that emitted the signal.
     @type node: L{Node}
     @param acc: The new accessible in the node.
-    @type acc: L{pyLinAcc.Accessible}
+    @type acc: L{Accessibility.Accessible}
     '''
     if self.isMyApp(acc):
       # Bad karma
@@ -539,23 +529,17 @@ class AccessibleTreeView(gtk.TreeView, Tools):
     else:
       cellrenderer.set_property('sensitive', True)
 
-  def _selectFunc(self, selection, model, path, is_selected):
+  def _selectFunc(self, path):
     '''
     A selection function. Does not allow his application's node to be selected.
 
-    @param selection: The given selection object.
-    @type selection: L{gtk.TreeSelection}
-    @param model:The treeview's data model.
-    @type model: L{AccessibleModel}
     @param path: The path to the selected row.
     @type path: tuple
-    @param is_selected: True if the path is selected.
-    @type is_selected: boolean
 
     @return: True if the row's accessible is not this app.
     @rtype: boolean
     '''
-    acc = model[path][COL_ACC]
+    acc = self.model[path][COL_ACC]
     return not self.isMyApp(acc)
 
   def _onRowActivated(self, treeview, path, view_column):
