@@ -13,8 +13,9 @@ is available at U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 import gtk
 import gtk.gdk
-import pyLinAcc
+import pyatspi
 import gobject
+from tools import Tools
 
 MAX_BLINKS = 4
 
@@ -28,17 +29,17 @@ class Bag(object):
   def __str__(self):
     return ', '.join(vars(self).keys())
 
-class Node(gobject.GObject):
+class Node(gobject.GObject, Tools):
   '''
   Node class that contains convient references to accessibility information 
   for the currently selected node. A L{Node} instance will emit an 
   'accessible-changed' signal when L{update} is called with a new accessible.
 
   @ivar desktop: The desktop accessible. It holds references to all the 
-  application L{pyLinAcc.Accessible}s
-  @type desktop: L{pyLinAcc.Accessible}
+  application L{Accessibility.Accessible}s
+  @type desktop: L{Accessibility.Accessible}
   @ivar acc: The currently selected accessible.
-  @type acc: L{pyLinAcc.Accessible}
+  @type acc: L{Accessibility.Accessible}
   @ivar extents: The extents of a given accessible.
   @type extents: L{Bag}
   '''
@@ -47,9 +48,7 @@ class Node(gobject.GObject):
                    gobject.TYPE_NONE, 
                    (gobject.TYPE_PYOBJECT,))}
   def __init__(self):
-    self.__dict__.update(pyLinAcc.Interfaces.__dict__)
-    self.__dict__.update(pyLinAcc.Constants.__dict__)
-    self.desktop = pyLinAcc.Registry.getDesktop(0)
+    self.desktop = pyatspi.Registry.getDesktop(0)
     self.acc = None
     self.extents = None
     gobject.GObject.__init__(self)
@@ -61,17 +60,17 @@ class Node(gobject.GObject):
     'accessible-changed' signal.
 
     @param acc: An accessible.
-    @type acc: L{pyLinAcc.Accessible}
+    @type acc: L{Accessibility.Accessible}
     '''
-    if not acc:
+    if not acc or self.isMyApp(acc):
       return
     self.acc = acc
     try:
-      i = pyLinAcc.Interfaces.IComponent(acc)
+      i = acc.queryComponent()
     except NotImplementedError:
       self.extents = Bag(x=0, y=0, width=0, height=0)
     else:
-      self.extents = i.getExtents(pyLinAcc.Constants.DESKTOP_COORDS)
+      self.extents = i.getExtents(pyatspi.DESKTOP_COORDS)
     self.blinkRect()
     self.emit('accessible_changed', acc)
   
